==> callback-2.00.tar.gz: callback/src/cb/force.c <==
/***************************************************************************
**			State University of Groningen
**				    ICCE
**
**			       Frank B. Brokken
**
**	Copyright (c) State University of Groningen, ICCE, the Netherlands.
** 
**			This file is part of callback.
**
**
****************************************************************************


Callback was originally developed by Karel Kubat (karel@icce.rug.nl)

Callback version 2.00 was developed by Frank B. Brokken (frank@icce.rug.nl)
who is, as of February 1995, the maintainer of the callback software.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
ICCE OR THE STATE UNIVERSITY OF GRONINGEN BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
IN THE SOFTWARE.

Except as contained in this notice, the name of the ICCE shall not be used in
advertising or otherwise to promote the sale, use or other dealings in this
Software without prior written authorization from the ICCE.

*/
#include "cbstat.h"

void force(char *who, char *where)
{
    register int
	uid,
	tid;

    log(log_on, "cb (call) %s at %s", who, where);

    if ((uid = lookuser(who)) == nusers)
	error("User '%s' unknown.", who);
	
    if ((tid = combine(uid, where)) == ntargets)
	error("Can't call %s for %s.", where, who);

    switch (destination[tid].mode)
    {
	case direct_mode:		/* direct requested ? */
	    error("Use telnet or VCs for direct logins.");

	case extra_mode:
	    ask_extra_number(uid, tid);	/* ask for extra destination */
	break;

	default:			/* to catch the phonemode */
    }
	
    tty_names(line[0]);				/* use line[0] */
    
    setcallback(uid, tid);			/* set the callback file */

    reinit();
}

==> callback-2.04.tar.gz: callback/src/cb/force.c <==
/***************************************************************************
**			State University of Groningen
**				    ICCE
**
**			       Frank B. Brokken
**
**	Copyright (c) State University of Groningen, ICCE, the Netherlands.
** 
**			This file is part of callback.
**
**
****************************************************************************


Callback was originally developed by Karel Kubat (karel@icce.rug.nl)

Callback version 2.00 was developed by Frank B. Brokken (frank@icce.rug.nl)
who is, as of February 1995, the maintainer of the callback software.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
ICCE OR THE STATE UNIVERSITY OF GRONINGEN BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
IN THE SOFTWARE.

Except as contained in this notice, the name of the ICCE shall not be used in
advertising or otherwise to promote the sale, use or other dealings in this
Software without prior written authorization from the ICCE.

*/
#include "cbstat.h"

void force(char *who, char *where)
{
    register int
	uid,
	did;

    log(log_on, "cb (call) %s at %s", who, where);

    if ((uid = lookuser(who)) == nusers)
	error("User '%s' unknown.", who);
	
    if ((did = combine(uid, where)) == ndestinations)
	error("Can't call %s for %s.", where, who);

    switch (destination[did].mode)
    {
	case direct_mode:		/* direct requested ? */
	    error("Use telnet or VCs for direct logins.");

	case extra_mode:
	    ask_extra_number(uid, did);	/* ask for extra destination */
	break;

	default:			/* to catch the phonemode */
    }
	
    tty_names(line[0]);				/* use line[0] */
    
    setcallback(uid, did);		/* set the callback file (no log) */

    reinit();
}
